@@ -115,7 +115,7 @@ def patch():
 @sleep_and_retry
 @limits(calls=_CALLS, period=_PERIOD)
 def serve_static_files(path):
-    return send_from_directory('docs/assets', path)
+    return send_from_directory('templates/assets', path)
 
 
 def main():
